# TODO Steps

- [X] Cleanup the `lib` folder.
- [ ] Add a LICENSE file, to be figured with Michalis as he is the code rights owner at the moment.
- [X] Clean up the Python code.
- [ ] Go over many implementation details with Michalis to add documentation.
- [X] Separate actual code and running + plotting scripts.
- [ ] Go over the Python modules and make a package (new repo). In time this should all be a `pip`-installable package implementing the same functionality. To discuss with Elias.
- [ ] Have a full API documentation of the new package, with a user guide -> how to use in `xsuite` simulations, options, caveats, etc.
- [ ] Speed up the code!

Remember to keep benchmarking at each step.